{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/input_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/input_index_file"
                },
                {
                    "type": "File",
                    "id": "#main/reference_file"
                },
                {
                    "type": "File",
                    "id": "#main/reference_index_file"
                },
                {
                    "type": "File",
                    "id": "#main/truth_md5sum_file"
                }
            ],
            "steps": [
                {
                    "run": "#CRAM_md5sum_checker.cwl",
                    "in": [
                        {
                            "source": "#main/md5sum/output_file",
                            "id": "#main/checker/input_file_1"
                        },
                        {
                            "source": "#main/truth_md5sum_file",
                            "id": "#main/checker/input_file_2"
                        }
                    ],
                    "out": [
                        "#main/checker/results_file"
                    ],
                    "id": "#main/checker"
                },
                {
                    "run": "#CRAM_md5sum.cwl",
                    "in": [
                        {
                            "source": "#main/input_file",
                            "id": "#main/md5sum/input_file"
                        },
                        {
                            "source": "#main/input_index_file",
                            "id": "#main/md5sum/input_index_file"
                        },
                        {
                            "source": "#main/reference_file",
                            "id": "#main/md5sum/reference_file"
                        },
                        {
                            "source": "#main/reference_index_file",
                            "id": "#main/md5sum/reference_index_file"
                        }
                    ],
                    "out": [
                        "#main/md5sum/output_file"
                    ],
                    "id": "#main/md5sum"
                }
            ],
            "doc": "This wraps the md5sum tool with a checker workflow that runs both the tool and a tool that performs verification of results\n",
            "id": "#main",
            "http://purl.org/dc/terms/creator": {
                "@id": "https://orcid.org/0000-0001-5173-4627",
                "foaf:name": "Walter Shands",
                "foaf:mbox": "jshands@ucsc.edu"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/checker/results_file",
                    "id": "#main/workflow_output_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#CRAM_md5sum_checker.cwl",
            "label": "A tool that checks the md5sum workflow",
            "hints": [
                {
                    "coresMin": 1,
                    "ramMin": 1024,
                    "outdirMin": 512,
                    "class": "ResourceRequirement"
                }
            ],
            "requirements": [
                {
                    "dockerPull": "us.gcr.io/broad-gotc-prod/genomes-in-the-cloud:2.3.2-1510681135",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "The first file that contains an md5sum.",
                    "id": "#CRAM_md5sum_checker.cwl/Md5sumWorkflowChecker/input_file_1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "The second file that contains an md5sum.",
                    "id": "#CRAM_md5sum_checker.cwl/Md5sumWorkflowChecker/input_file_2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "A file that contains the result of the diff.",
                    "id": "#CRAM_md5sum_checker.cwl/Md5sumWorkflowChecker/results_file",
                    "outputBinding": {
                        "glob": "md5sum_diff.txt"
                    }
                }
            ],
            "stdout": "md5sum_diff.txt",
            "baseCommand": [
                "diff"
            ]
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#CRAM_md5sum.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#CRAM_md5sum.cwl/input_index_file"
                },
                {
                    "type": "File",
                    "id": "#CRAM_md5sum.cwl/reference_file"
                },
                {
                    "type": "File",
                    "id": "#CRAM_md5sum.cwl/reference_index_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#CRAM_md5sum.cwl/CRAM_md5sum/output_file",
                    "id": "#CRAM_md5sum.cwl/output_file"
                }
            ],
            "steps": [
                {
                    "run": "#CRAM_tool_md5sum.cwl",
                    "in": [
                        {
                            "source": "#CRAM_md5sum.cwl/CRAM_samtools/output_file",
                            "id": "#CRAM_md5sum.cwl/CRAM_md5sum/input_file"
                        }
                    ],
                    "out": [
                        "#CRAM_md5sum.cwl/CRAM_md5sum/output_file"
                    ],
                    "id": "#CRAM_md5sum.cwl/CRAM_md5sum"
                },
                {
                    "run": "#CRAM_tool_samtools.cwl",
                    "in": [
                        {
                            "source": "#CRAM_md5sum.cwl/input_file",
                            "id": "#CRAM_md5sum.cwl/CRAM_samtools/input_file"
                        },
                        {
                            "source": "#CRAM_md5sum.cwl/input_index_file",
                            "id": "#CRAM_md5sum.cwl/CRAM_samtools/input_index_file"
                        },
                        {
                            "source": "#CRAM_md5sum.cwl/reference_file",
                            "id": "#CRAM_md5sum.cwl/CRAM_samtools/reference_file"
                        },
                        {
                            "source": "#CRAM_md5sum.cwl/reference_index_file",
                            "id": "#CRAM_md5sum.cwl/CRAM_samtools/reference_index_file"
                        }
                    ],
                    "out": [
                        "#CRAM_md5sum.cwl/CRAM_samtools/output_file"
                    ],
                    "id": "#CRAM_md5sum.cwl/CRAM_samtools"
                }
            ],
            "id": "#CRAM_md5sum.cwl",
            "http://purl.org/dc/terms/creator": {
                "@id": "https://orcid.org/0000-0001-5173-4627",
                "foaf:name": "Walter Shands",
                "foaf:mbox": "jshands@ucsc.edu"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#CRAM_tool_md5sum.cwl",
            "label": "md5sum tool",
            "hints": [
                {
                    "coresMin": 1,
                    "ramMin": 1024,
                    "outdirMin": 512,
                    "class": "ResourceRequirement"
                }
            ],
            "requirements": [
                {
                    "dockerPull": "us.gcr.io/broad-gotc-prod/genomes-in-the-cloud:2.3.2-1510681135",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "The SAM file that will have its md5sum calculated.",
                    "id": "#CRAM_tool_md5sum.cwl/CRAM_md5sum/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/data_3671",
                    "doc": "A text file containing the md5sum of the input SAM file.",
                    "id": "#CRAM_tool_md5sum.cwl/CRAM_md5sum/output_file",
                    "outputBinding": {
                        "glob": "$(inputs.input_file[\"basename\"])_md5sum.txt"
                    }
                }
            ],
            "stdout": "$(inputs.input_file[\"basename\"])_md5sum.txt",
            "baseCommand": [
                "md5sum"
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "https://orcid.org/0000-0001-5173-4627",
                "http://xmlns.com/foaf/0.1/name": "Walter Shands",
                "http://xmlns.com/foaf/0.1/mbox": "jshands@ucsc.edu"
            },
            "stdin": "$(inputs.input_file.path)"
        },
        {
            "class": "CommandLineTool",
            "id": "#CRAM_tool_samtools.cwl",
            "label": "samtools tool",
            "requirements": [
                {
                    "dockerPull": "us.gcr.io/broad-gotc-prod/genomes-in-the-cloud:2.3.2-1510681135",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.input_file)",
                        "$(inputs.reference_file)",
                        "$(inputs.reference_index_file)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 1024,
                    "outdirMin": 100000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "The BAM or CRAM file that will be converted to a SAM file with no header.",
                    "id": "#CRAM_tool_samtools.cwl/CRAM_samtools/input_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "The index file for the input CRAM or BAM file.",
                    "id": "#CRAM_tool_samtools.cwl/CRAM_samtools/input_index_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-T"
                    },
                    "doc": "The genome reference file for the BAM or CRAM file.",
                    "id": "#CRAM_tool_samtools.cwl/CRAM_samtools/reference_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-t"
                    },
                    "doc": "The index file for the genome reference file.",
                    "id": "#CRAM_tool_samtools.cwl/CRAM_samtools/reference_index_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2573",
                    "doc": "A SAM file with no header.",
                    "id": "#CRAM_tool_samtools.cwl/CRAM_samtools/output_file",
                    "outputBinding": {
                        "glob": "$(inputs.input_file[\"basename\"]).sam"
                    }
                }
            ],
            "stdout": "$(inputs.input_file[\"basename\"]).sam",
            "baseCommand": [
                "samtools",
                "view"
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "https://orcid.org/0000-0001-5173-4627",
                "http://xmlns.com/foaf/0.1/name": "Walter Shands",
                "http://xmlns.com/foaf/0.1/mbox": "jshands@ucsc.edu"
            }
        }
    ],
    "cwlVersion": "v1.0"
}
